@@ -37,6 +37,7 @@
   #:use-module (cv init)
   #:use-module (cv support)
   #:use-module (cv idata)
+  #:use-module (cv imgproc)
   #:use-module (cv segmentation)
   #:use-module (cv properties)
   
@@ -68,7 +69,8 @@
             im-transpose-channel
             im-normalize
             im-normalize-channel
-            im-scrap))
+            im-scrap
+            im-particles))
 
 
 #;(g-export )
@@ -461,3 +463,10 @@ Target.B = ((1 - Source.A) * BGColor.B) + (Source.A * Source.B)
                             0.0
                             (f32vector-ref channel i)))))
     to))
+
+(define (im-particles image properties)
+  (par-map (lambda (prop)
+             (match prop
+               ((area left top right bottom . rest)
+                (im-crop image left top (+ right 1) (+ bottom 1)))))
+      properties))
